@@ -25,7 +25,12 @@ from airflow.models import Connection
 from airflow.providers.apache.kafka.hooks.consume import KafkaConsumerHook
 from airflow.providers.apache.kafka.triggers.await_message import AwaitMessageTrigger
 
-from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS, get_base_airflow_version_tuple
+from tests_common.test_utils.common_msg_queue import (
+    collect_queue_param_deprecation_warning,
+    mark_common_msg_queue_test,
+)
+
+USED_FIXTURES = [collect_queue_param_deprecation_warning]
 
 
 def apply_function_false(message):
@@ -94,13 +99,20 @@ class TestTrigger:
             poll_interval=5,
         )
 
+    @pytest.mark.parametrize(
+        "apply_function",
+        [
+            "unit.apache.kafka.triggers.test_await_message.apply_function_true",
+            None,
+        ],
+    )
     @pytest.mark.asyncio
-    async def test_trigger_run_good(self, mocker):
+    async def test_trigger_run_good(self, mocker, apply_function):
         mocker.patch.object(KafkaConsumerHook, "get_consumer", return_value=MockedConsumer)
 
         trigger = AwaitMessageTrigger(
             kafka_config_id="kafka_d",
-            apply_function="unit.apache.kafka.triggers.test_await_message.apply_function_true",
+            apply_function=apply_function,
             topics=["noop"],
             poll_timeout=0.0001,
             poll_interval=5,
@@ -129,14 +141,21 @@ class TestTrigger:
         asyncio.get_event_loop().stop()
 
 
-@pytest.mark.skipif(not AIRFLOW_V_3_0_PLUS, reason="Requires Airflow 3.0.+")
+@mark_common_msg_queue_test
 class TestMessageQueueTrigger:
-    def test_provider_integrations(self, cleanup_providers_manager):
-        if get_base_airflow_version_tuple() < (3, 0, 1):
-            pytest.skip("This test is only for Airflow 3.0.1+")
-
+    @pytest.mark.usefixtures("collect_queue_param_deprecation_warning")
+    def test_provider_integrations_with_queue_param(self, cleanup_providers_manager):
         queue = "kafka://localhost:9092/topic1"
+
         from airflow.providers.common.messaging.triggers.msg_queue import MessageQueueTrigger
 
         trigger = MessageQueueTrigger(queue=queue, apply_function="mock_kafka_trigger_apply_function")
         assert isinstance(trigger.trigger, AwaitMessageTrigger)
+
+    def test_provider_integrations_with_scheme_param(self, cleanup_providers_manager):
+        from airflow.providers.common.messaging.triggers.msg_queue import MessageQueueTrigger
+
+        trigger = MessageQueueTrigger(
+            scheme="kafka", apply_function="mock_kafka_trigger_apply_function", topics=["topic1"]
+        )
+        assert isinstance(trigger.trigger, AwaitMessageTrigger)
